package dns

import (
	"fmt"
	"testing"
)

func TestRecordCompare(t *testing.T) {
	names := []struct {
		first  string
		second string
	}{
		{"a.", "b."},
		{"a.", "a.a."},
		{"b.", "a.c."},
		{"a.a.", "b.a."},
		{"b.a.", "a.b."},

		{"iris.majava.org.", "mamaku.majava.org."},
		{"_domainkey.iris.majava.org.", "mamaku.majava.org."},
		{"mamaku-ed25519._domainkey.iris.majava.org.", "mamaku.majava.org."},
	}

	for _, testCase := range names {
		t.Run(fmt.Sprintf("%s < %s", testCase.first, testCase.second), func(t *testing.T) {
			first := Record{
				Name:  testCase.first,
				Type:  RecordTypeA,
				Value: "192.0.2.1",
			}
			second := Record{
				Name:  testCase.second,
				Type:  RecordTypeA,
				Value: "192.0.2.1",
			}

			if !first.Compare(second) {
				t.Fatalf("%v should sort before %v", testCase.first, testCase.second)
			}
		})
	}
}

func TestRecordCompareType(t *testing.T) {
	first := Record{
		Name:  "example.",
		Type:  RecordTypeA,
		Value: "192.0.2.1",
	}
	second := Record{
		Name:  "example.",
		Type:  RecordTypeAAAA,
		Value: "0::1",
	}

	if !first.Compare(second) {
		t.Fatalf("%v %v should sort before %v %v", first.Type, first.Value, second.Type, second.Value)
	}
}
