package dns

import (
	"net"
	"testing"
)

func TestGetReverseNameIpv4(t *testing.T) {
	addrs := []struct {
		address  string
		expected string
	}{
		{"1.2.3.4", "4.3.2.1.in-addr.arpa."},
		{"0.0.0.0", "0.0.0.0.in-addr.arpa."},
		{"255.255.255.255", "255.255.255.255.in-addr.arpa."},
		{"127.100.200.1", "1.200.100.127.in-addr.arpa."},
	}
	for _, testCase := range addrs {
		t.Run(testCase.address, func(t *testing.T) {
			addr := net.ParseIP(testCase.address)
			value := GetReverseName(addr, RecordTypeA)
			if value != testCase.expected {
				t.Errorf("For %v, wanted %v but got %v", testCase.address, testCase.expected, value)
			}
		})
	}
}

func TestGetReverseNameIpv6(t *testing.T) {
	addrs := []struct {
		address  string
		expected string
	}{
		{"2001:db8::567:89ab", "b.a.9.8.7.6.5.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.8.b.d.0.1.0.0.2.ip6.arpa."},
		{"2620:0:862:ed1a::1", "1.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.a.1.d.e.2.6.8.0.0.0.0.0.0.2.6.2.ip6.arpa."},
	}
	for _, testCase := range addrs {
		t.Run(testCase.address, func(t *testing.T) {
			addr := net.ParseIP(testCase.address)
			value := GetReverseName(addr, RecordTypeAAAA)
			if value != testCase.expected {
				t.Errorf("For %v, wanted %v but got %v", testCase.address, testCase.expected, value)
			}
		})
	}
}
