package dns

import (
	"fmt"
	"sort"
	"strings"
)

type ZoneFile struct {
	Zone    string
	Records []Record
}

func (z ZoneFile) Render() string {
	longestName := 0
	for _, record := range z.Records {
		length := len(strings.TrimSuffix(record.Name, "."+z.Zone))
		if record.Name == z.Zone {
			length = 1
		}

		if length > longestName {
			longestName = length
		}
	}

	ret := ""

	sort.Slice(z.Records, func(i, j int) bool {
		return z.Records[i].Compare(z.Records[j])
	})

	for _, record := range z.Records {
		name := strings.TrimSuffix(record.Name, "."+z.Zone)
		if record.Name == z.Zone {
			name = "@"
		}

		ret += fmt.Sprintf("%-*s IN %-*s %v\n", longestName, name, LongestRecordTypeLength, record.Type, record.Value)
	}

	return ret
}
