package webproxy

import (
	"encoding/json"
	"net/http"

	"git.majava.org/software/dnsgen/pkg/config"
	"git.majava.org/software/dnsgen/pkg/dns"
)

type proxyData struct {
	Hosts []string `json:"hosts"`
}

func GetRecords(cfg config.WebProxy) ([]dns.Record, error) {
	records := []dns.Record{}

	resp, err := http.Get(cfg.MetadataUrl)
	if err != nil {
		return nil, err
	}
	defer resp.Body.Close()

	var data map[string]proxyData
	err = json.NewDecoder(resp.Body).Decode(&data)
	if err != nil {
		return nil, err
	}

	for _, proxy := range data {
		for _, host := range proxy.Hosts {
			isSkipped := false
			for _, skip := range cfg.Skip {
				if skip == host {
					isSkipped = true
					break
				}
			}
			if isSkipped {
				continue
			}

			records = append(records, dns.Record{
				Name:  host + ".",
				Type:  dns.RecordTypeCNAME,
				Value: cfg.ProxyTarget,
			})
		}
	}

	return records, nil
}
